Eip712Domain class
Constructors
- Eip712Domain({String name = escrowContractName, String version = escrowContractVersion, int chainId = 8453, String verifyingContract = '0x0000000000000000000000000000000000000000'})
-
const
Properties
- chainId → int
-
final
- domainSeparator → String
-
no setter
- domainSeparatorBytes → Uint8List
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verifyingContract → String
-
final
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited