MarketSigner class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
publicKeyBase64()
→ String
-
-
publicKeyHex()
→ String
-
-
requestId(String intent)
→ String
-
-
signCanonical(String canonical)
→ String
-
-
signDebitAuthorization({required String channelId, required String hub, required String token, required BigInt amount, required String receiptId, required BigInt nonce, required int deadline, int chainId = 8453, String verifyingContract = '0x0000000000000000000000000000000000000000'})
→ String
-
-
-
signEip712TypedData(TypedData data)
→ String
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
verify(String publicKey, String signature, String canonical)
→ bool
-
-
verifyHubSignature(String hubPublicKey, String message, String signature)
→ bool
-